Op

Enum Op 

pub enum Op {
Show 70 variants Save, Restore, Concat(Matrix), SetLineWidth(f32), SetLineCap(i32), SetLineJoin(i32), SetMiterLimit(f32), SetDash(Vec<f32>, f32), SetRenderingIntent(Name), SetFlatness(f32), SetExtGState(Name), MoveTo(f32, f32), LineTo(f32, f32), CurveTo(f32, f32, f32, f32, f32, f32), CurveToV(f32, f32, f32, f32), CurveToY(f32, f32, f32, f32), ClosePath, Rect(f32, f32, f32, f32), Stroke, CloseStroke, Fill, FillEvenOdd, FillStroke, FillStrokeEvenOdd, CloseFillStroke, CloseFillStrokeEvenOdd, EndPath, ClipNonZero, ClipEvenOdd, SetStrokeColorSpace(Name), SetFillColorSpace(Name), SetStrokeColor(Vec<f32>), SetStrokeColorN(Vec<f32>, Option<Name>), SetFillColor(Vec<f32>), SetFillColorN(Vec<f32>, Option<Name>), SetStrokeGray(f32), SetFillGray(f32), SetStrokeRGB(f32, f32, f32), SetFillRGB(f32, f32, f32), SetStrokeCMYK(f32, f32, f32, f32), SetFillCMYK(f32, f32, f32, f32), BeginText, EndText, SetCharSpacing(f32), SetWordSpacing(f32), SetHorizScaling(f32), SetLeading(f32), SetFont(Name, f32), SetGlyphWidth(f32, f32), SetGlyphWidthBBox(f32, f32, f32, f32, f32, f32), SetTextRender(i32), SetTextRise(f32), TextMove(f32, f32), TextMoveSetLeading(f32, f32), SetTextMatrix(Matrix), TextNextLine, ShowText(Vec<u8>), ShowTextAdjusted(Vec<TextItem>), NextLineShowText(Vec<u8>), NextLineShowTextSpaced(f32, f32, Vec<u8>), XObject(Name), InlineImage(ImageParams), Shading(Name), MarkedContentPoint(Name), MarkedContentPointProps(Name, Object), BeginMarkedContent(Name), BeginMarkedContentProps(Name, Object), EndMarkedContent, BeginCompat, EndCompat,
}
A parsed content-stream operator with its operands.

Variants



Save

q



Restore

Q



Concat(Matrix)

cm



SetLineWidth(f32)

w



SetLineCap(i32)

J



SetLineJoin(i32)

j



SetMiterLimit(f32)

M



SetDash(Vec<f32>, f32)

d (dash array, phase)



SetRenderingIntent(Name)

ri



SetFlatness(f32)

i



SetExtGState(Name)

gs



MoveTo(f32, f32)

m



LineTo(f32, f32)

l



CurveTo(f32, f32, f32, f32, f32, f32)

c



CurveToV(f32, f32, f32, f32)

v (first control point = current point)



CurveToY(f32, f32, f32, f32)

y (second control point = end point)



ClosePath

h



Rect(f32, f32, f32, f32)

re (x, y, width, height)



Stroke

S



CloseStroke

s



Fill

f / F



FillEvenOdd

f*



FillStroke

B



FillStrokeEvenOdd

B*



CloseFillStroke

b



CloseFillStrokeEvenOdd

b*



EndPath

n



ClipNonZero

W



ClipEvenOdd

W*



SetStrokeColorSpace(Name)

CS



SetFillColorSpace(Name)

cs



SetStrokeColor(Vec<f32>)

SC



SetStrokeColorN(Vec<f32>, Option<Name>)

SCN (components, optional pattern name)



SetFillColor(Vec<f32>)

sc



SetFillColorN(Vec<f32>, Option<Name>)

scn (components, optional pattern name)



SetStrokeGray(f32)

G



SetFillGray(f32)

g



SetStrokeRGB(f32, f32, f32)

RG



SetFillRGB(f32, f32, f32)

rg



SetStrokeCMYK(f32, f32, f32, f32)

K



SetFillCMYK(f32, f32, f32, f32)

k



BeginText

BT



EndText

ET



SetCharSpacing(f32)

Tc



SetWordSpacing(f32)

Tw



SetHorizScaling(f32)

Tz



SetLeading(f32)

TL



SetFont(Name, f32)

Tf (font resource name, size)



SetGlyphWidth(f32, f32)

d0 (wx, wy): sets the glyph width for a colored Type3 glyph, whose content sets its own color (ISO 32000-1 Table 113).



SetGlyphWidthBBox(f32, f32, f32, f32, f32, f32)

d1 (wx, wy, llx, lly, urx, ury): sets the glyph width and bounding box for an uncolored Type3 glyph description; color comes from the text state and color operators in the proc are ignored (ISO 32000-1 Table 113).



SetTextRender(i32)

Tr



SetTextRise(f32)

Ts



TextMove(f32, f32)

Td



TextMoveSetLeading(f32, f32)

TD



SetTextMatrix(Matrix)

Tm



TextNextLine

T*



ShowText(Vec<u8>)

Tj



ShowTextAdjusted(Vec<TextItem>)

TJ



NextLineShowText(Vec<u8>)

'



NextLineShowTextSpaced(f32, f32, Vec<u8>)

" (word spacing, char spacing, string)



XObject(Name)

Do



InlineImage(ImageParams)

BI ... ID ... EI



Shading(Name)

sh



MarkedContentPoint(Name)

MP



MarkedContentPointProps(Name, Object)

DP (tag, properties: inline dict or resource name)



BeginMarkedContent(Name)

BMC



BeginMarkedContentProps(Name, Object)

BDC (tag, properties: inline dict or resource name)



EndMarkedContent

EMC



BeginCompat

BX



EndCompat

EX