Matrix

Struct Matrix 

pub struct Matrix {
    pub a: f32,
    pub b: f32,
    pub c: f32,
    pub d: f32,
    pub e: f32,
    pub f: f32,
}
A 2-D affine transformation [a b c d e f] in the PDF convention:

x' = a·x + c·y + e
y' = b·x + d·y + f

Fields

a: f32b: f32c: f32d: f32e: f32f: f32

Implementations

Source

impl Matrix

pub const fn identity() -> Matrix

The identity transformation.

pub const fn translate(tx: f32, ty: f32) -> Matrix

Translation by (tx, ty).

pub const fn scale(sx: f32, sy: f32) -> Matrix

Scaling by (sx, sy) about the origin.

pub fn rotate_deg(deg: f32) -> Matrix

Counter-clockwise rotation by deg degrees about the origin.

pub fn concat(self, other: Matrix) -> Matrix

Composition “apply self first, then other”.

With the row-vector convention this is the matrix product self × other, so p.apply(self.concat(other)) == other.apply(self.apply(p)).

pub fn apply(self, p: Point) -> Point

Transforms a point.

pub fn invert(self) -> Option<Matrix>

The inverse transformation, or None if self is singular (determinant zero or non-finite).